"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.autonomies = void 0;
const autonomies_json_1 = __importDefault(require("./data/autonomies.json"));
const cities_1 = require("./cities");
const provinces_1 = require("./provinces");
/**
 * Returns an array of autonomies that match the specified filter criteria.
 * @param filters (optional) An object with filters.
 * @param filters.code A string or number representing the code of the autonomy to filter by.
 * @param filters.name A string representing the name of the autonomy to filter by.
 * @param filters.with_provinces A boolean indicating if the result should include provinces associated with each autonomy.
 * @param filters.with_cities A boolean indicating if the result should include cities associated with each autonomy.
 */
const autonomies = (filters = {}) => {
    const { code, name, with_provinces = false, with_cities = false } = filters;
    const filtered = autonomies_json_1.default.filter((autonomy) => (code === undefined || autonomy.code == code) &&
        (name === undefined || autonomy.name.toLocaleLowerCase().includes(name.toLocaleLowerCase())));
    return filtered.map((autonomy) => (Object.assign(Object.assign(Object.assign({}, autonomy), (with_provinces && { provinces: (0, provinces_1.provinces)({ code_autonomy: autonomy.code }) })), (with_cities && { cities: (0, cities_1.cities)({ code_autonomy: autonomy.code }) }))));
};
exports.autonomies = autonomies;
