"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.provinces = void 0;
const autonomies_1 = require("./autonomies");
const cities_1 = require("./cities");
const provinces_json_1 = __importDefault(require("./data/provinces.json"));
/**
 * Returns an array of provinces that match the specified filter criteria.
 * @param filters (optional) An object with filters.
 * @param filters.code A string or number representing the code of the province to filter by.
 * @param filters.code_autonomy A string or number representing the code of the autonomy to filter by.
 * @param filters.name A string representing the name of the province to filter by.
 * @param filters.with_autonomy A boolean indicating if the result should include the autonomy associated with each province.
 * @param filters.with_cities A boolean indicating if the result should include cities associated with each province.
 */
const provinces = (filters = {}) => {
    const { code, code_autonomy, name, with_autonomy = false, with_cities = false } = filters;
    const filtered = provinces_json_1.default.filter((province) => (code === undefined || province.code == code) &&
        (code_autonomy === undefined || province.code_autonomy == code_autonomy) &&
        (name === undefined || province.name.toLocaleLowerCase().includes(name.toLocaleLowerCase())));
    return filtered.map((province) => (Object.assign(Object.assign(Object.assign({}, province), (with_autonomy && { autonomy: (0, autonomies_1.autonomies)({ code: province.code_autonomy })[0] })), (with_cities && { cities: (0, cities_1.cities)({ code_province: province.code }) }))));
};
exports.provinces = provinces;
